@@ -45,6 +45,7 @@
 #define HAVE_INTTYPES_H 1
 /* #undef HAVE_KQUEUE */
 #define HAVE_LIMITS_H 1
+#define HAVE_LINK_H 1
 #define HAVE_LINUX_UNISTD_H 1
 #define HAVE_LOCALE_H 1
 #define HAVE_MALLOC_H 1
@@ -86,6 +87,7 @@
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
+#define HAVE_SYS_SYSCALL_H 1
 /* #undef HAVE_SYS_TERMCAP_H */
 /* #undef HAVE_SYS_TIMEB_H */
 #define HAVE_SYS_TIMES_H 1
@@ -93,6 +95,7 @@
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
+#define HAVE_SYS_STATVFS_H 1
 #define HAVE_UCONTEXT_H 1
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
@@ -118,6 +121,7 @@
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBMTMALLOC */
 /* #undef HAVE_LIBWRAP */
+#define HAVE_SYSTEMD 1
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
@@ -163,6 +167,7 @@
 #define HAVE_FSYNC 1
 #define HAVE_FTIME 1
 #define HAVE_GETADDRINFO 1
+#define HAVE_GETIFADDRS 1
 #define HAVE_GETCWD 1
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
@@ -214,9 +219,13 @@
 #define HAVE_POLL 1
 /* #undef HAVE_PORT_CREATE */
 #define HAVE_POSIX_FALLOCATE 1
+#define HAVE_LINUX_FALLOC_H 1
+#define HAVE_FALLOCATE 1
+#define HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE 1
 #define HAVE_PREAD 1
 #define HAVE_PAUSE_INSTRUCTION 1
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
+/* #undef HAVE_HMT_PRIORITY_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
@@ -398,7 +407,7 @@
 
 #define HAVE_MBSTATE_T 1
 
-#define MAX_INDEXES 64
+#define MAX_INDEXES 64U
 
 #define QSORT_TYPE_IS_VOID 1
 #define RETQSORTTYPE void
@@ -460,7 +469,7 @@
 
 #define HAVE_WEAK_SYMBOL 1
 #define HAVE_ABI_CXA_DEMANGLE 1
-
+#define HAVE_ATTRIBUTE_CLEANUP 1
 
 #define HAVE_POSIX_SIGNALS 1
 /* #undef HAVE_BSD_SIGNALS */
@@ -471,7 +480,6 @@
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
 /* #undef MY_ATOMIC_MODE_DUMMY */
-/* #undef MY_ATOMIC_MODE_RWLOCKS */
 #define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
@@ -538,7 +546,6 @@
 #define ENABLED_LOCAL_INFILE 1
 #define ENABLED_PROFILING 1
 /* #undef EXTRA_DEBUG */
-/* #undef BACKUP_TEST */
 /* #undef CYBOZU */
 /* #undef USE_SYMDIR */
 
@@ -594,7 +601,8 @@
 #define HAVE_CHARSET_utf32 1
 #define HAVE_UCA_COLLATIONS 1
 #define HAVE_COMPRESS 1
-
+#define HAVE_EncryptAes128Ctr 1
+#define HAVE_EncryptAes128Gcm 1
 
 /*
   Stuff that always need to be defined (compile breaks without it)
@@ -611,15 +619,11 @@
 #define WITH_MYISAM_STORAGE_ENGINE 1
 #define WITH_MYISAMMRG_STORAGE_ENGINE 1
 #define WITH_HEAP_STORAGE_ENGINE 1
-#define WITH_INNOBASE_STORAGE_ENGINE 1
+/* #undef WITH_INNOBASE_STORAGE_ENGINE */
 #define WITH_XTRADB_STORAGE_ENGINE 1
 #define WITH_CSV_STORAGE_ENGINE 1
 #define WITH_PARTITION_STORAGE_ENGINE 1
 #define WITH_PERFSCHEMA_STORAGE_ENGINE 1
-/* #undef WITH_NDBCLUSTER_STORAGE_ENGINE */
-#if (WITH_NDBCLUSTER_STORAGE_ENGINE) && !defined(EMBEDDED_LIBRARY)
-# define HAVE_NDB_BINLOG 1
-#endif
 #define WITH_ARIA_STORAGE_ENGINE 1
 #define USE_ARIA_FOR_TMP_TABLES 1
 
@@ -635,26 +639,32 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 31
+#define MYSQL_VERSION_MINOR 1
+#define MYSQL_VERSION_PATCH 25
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.31"
+#define PACKAGE_STRING "MySQL Server 10.1.25"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.31"
-#define VERSION "10.0.31"
+#define PACKAGE_VERSION "10.1.25"
+#define VERSION "10.1.25"
 #define PROTOCOL_VERSION 10
 
-#define MALLOC_LIBRARY "bundled jemalloc"
+#define MALLOC_LIBRARY "system"
 
 /* time_t related defines */
 
 #define SIZEOF_TIME_T 8
 /* #undef TIME_T_UNSIGNED */
 
+#ifndef EMBEDDED_LIBRARY
+/* #undef WSREP_INTERFACE_VERSION */
+#define WITH_WSREP 1
+#define WSREP_PROC_INFO 1
+#endif
+
 #ifdef _AIX
 /*
   AIX includes inttypes.h from sys/types.h
